==> ejc-bfyjerp-api-3.0.0-20250117.092456-107-sources.jar: com/ejianc/business/oa/vo/CertSalaryDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-证书人员工资表子表
 * 
 * @author generator
 * 
 */
public class CertSalaryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long certSalaryId; // 证书人员工资主表id
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date certSalaryMonth; // 主表月份
    private String name; // 姓名
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别名称
    private BigDecimal salaryMny; // 应发工资
    private BigDecimal otherPayMny; // 其他应付款
    private BigDecimal otherDeductMny; // 其他扣款
    private BigDecimal actualSalaryMny; // 实发工资
    private BigDecimal certMny; // 证书费用
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date inDate; // 迁入日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate; // 结束日期
    private String cert; // 证书明细
    private String certName; // 证书明细
    private Long sourceId; // 来源id即证书人员id

    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }

    public Long getCertSalaryId() {
        return certSalaryId;
    }

    public void setCertSalaryId(Long certSalaryId) {
        this.certSalaryId = certSalaryId;
    }
    public Date getCertSalaryMonth() {
        return certSalaryMonth;
    }

    public void setCertSalaryMonth(Date certSalaryMonth) {
        this.certSalaryMonth = certSalaryMonth;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public Date getInDate() {
        return inDate;
    }

    public void setInDate(Date inDate) {
        this.inDate = inDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250411.101137-195-sources.jar: com/ejianc/business/oa/vo/CertSalaryDetailVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人力行政-证书人员工资表子表
 * 
 * @author generator
 * 
 */
public class CertSalaryDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long certSalaryId; // 证书人员工资主表id
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date certSalaryMonth; // 主表月份
    private String name; // 姓名
    private Integer humanType; // 人员类别
    private String humanTypeName; // 人员类别名称
    private BigDecimal salaryMny; // 应发工资
    private BigDecimal otherPayMny; // 其他应付款
    private BigDecimal otherDeductMny; // 其他扣款
    private BigDecimal actualSalaryMny; // 实发工资
    private BigDecimal certMny; // 证书费用
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date inDate; // 迁入日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endDate; // 结束日期
    private String cert; // 证书明细
    private String certName; // 证书明细
    private Long sourceId; // 来源id即证书人员id
    private Integer payType; // 付款方式
    private String payTypeName; // 付款方式

    public Integer getPayType() {
        return payType;
    }

    public void setPayType(Integer payType) {
        this.payType = payType;
    }

    public String getPayTypeName() {
        return payTypeName;
    }

    public void setPayTypeName(String payTypeName) {
        this.payTypeName = payTypeName;
    }

    public BigDecimal getCertMny() {
        return certMny;
    }

    public void setCertMny(BigDecimal certMny) {
        this.certMny = certMny;
    }

    public Long getCertSalaryId() {
        return certSalaryId;
    }

    public void setCertSalaryId(Long certSalaryId) {
        this.certSalaryId = certSalaryId;
    }
    public Date getCertSalaryMonth() {
        return certSalaryMonth;
    }

    public void setCertSalaryMonth(Date certSalaryMonth) {
        this.certSalaryMonth = certSalaryMonth;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getOtherPayMny() {
        return otherPayMny;
    }

    public void setOtherPayMny(BigDecimal otherPayMny) {
        this.otherPayMny = otherPayMny;
    }
    public BigDecimal getOtherDeductMny() {
        return otherDeductMny;
    }

    public void setOtherDeductMny(BigDecimal otherDeductMny) {
        this.otherDeductMny = otherDeductMny;
    }
    public BigDecimal getActualSalaryMny() {
        return actualSalaryMny;
    }

    public void setActualSalaryMny(BigDecimal actualSalaryMny) {
        this.actualSalaryMny = actualSalaryMny;
    }
    public Date getInDate() {
        return inDate;
    }

    public void setInDate(Date inDate) {
        this.inDate = inDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getCert() {
        return cert;
    }

    public void setCert(String cert) {
        this.cert = cert;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
